@@ -207,10 +207,15 @@ def log_ticks(
     base: int | float = int(10),
     axis: plt.Axes = None,
     direction: str = "x",
-    minor: bool = False,
+    minor: bool = True,
 ) -> (list, list):
     """
-    Get ticks and tick-labels between two bounds. For example::
+    Get and/or apply major ticks and tick-labels between two bounds.
+    Example: select a fraction of the default major ticks along an axis::
+
+        log_ticks(keep=[0, -1], axis=ax)
+
+    Example: get ticks and labels (without applying them to a plot)::
 
         >>> ticks, labels = log_ticks((0, 3))
         >>> print(ticks)
@@ -218,12 +223,12 @@ def log_ticks(
         >>> print(labels)
         ['$10^{0}$', '$10^{1}$', '$10^{2}$', '$10^{3}$']
 
-    :param lim: Lower- and upper-bound exponent. Default: read from ``axis`` or ``plt.gca()``,
-    :param keep: Convert labels to empty strings.
+    :param lim: Lower- and upper-bound exponent. Default: read from ``axis`` or ``plt.gca()``.
+    :param keep: Keep only a selection of labels, convert the rest to empty strings.
     :param base: The base of the exponents.
-    :param axis: Apply ticks/labels to an axis.
+    :param axis: Apply ticks/labels to an axis. Ticks are only applied if the axis is specified.
     :param direction: "x" or "y".
-    :param minor: Use minor ticks: minor ticks are placed without labels.
+    :param minor: Use minor ticks: minor ticks are placed without labels, they are not returned.
     :return: ticks, labels
     """
 
@@ -304,16 +309,25 @@ def log_minorticks(
     keep: list = None,
     axis: plt.Axes = None,
     direction: str = "x",
-    integer: bool = False,
 ) -> (list, list):
     """
-    Get minor ticks and tick-labels between two bounds.
+    Get and/or apply minor ticks and tick-labels between two bounds.
+    Example: select a fraction of the default minor ticks along an axis::
+
+        log_minorticks(keep=[0, -1], axis=ax)
+
+    Example: get ticks and labels (without applying them to a plot)::
+
+        >>> ticks, labels = log_ticks((0, 1))
+        >>> print(ticks)
+        [2, 3, 4, 5, 6, 7, 8, 9]
+        >>> print(labels)
+        ["2", "3", "4", "5", "6", "7", "8", "9"]
 
     :param lim: Lower- and upper-bound. Default: read from ``axis`` or ``plt.gca()``,
-    :param keep: Convert labels to empty strings, except at given indices.
-    :param axis: Apply ticks/labels to an axis.
+    :param keep: Keep only a selection of labels, convert the rest to empty strings.
+    :param axis: Apply ticks/labels to an axis. Ticks are only applied if the axis is specified.
     :param direction: "x" or "y".
-    :param integer: Show numbers as integer (if possible).
     :return: ticks, labels
     """
 
@@ -342,16 +356,16 @@ def log_minorticks(
 
     for i in range(exp_lower, exp_upper):
 
-        t = list((10 ** i) * np.arange(2, 10, dtype=float))
+        t = (10 ** i) * np.arange(2, 10, dtype=float)
 
         if i < 0:
+            t = np.around(t, -i)
             fmt = "{0:.0%df}" % np.abs(i)
-        elif integer:
-            fmt = "{0:.0f}"
         else:
-            fmt = "{0:.01f}"
+            t = np.around(t, i)
+            fmt = "{0:.0f}"
 
-        ticks += t
+        ticks += t.tolist()
         labels += [fmt.format(i) for i in t]
 
     ticks = np.array(ticks)
@@ -1243,6 +1257,8 @@ def fit_powerlaw(
     exponent: float = None,
     axis: plt.Axes = None,
     fmt: str = None,
+    auto_fmt: str = None,
+    extrapolate: bool | dict = False,
     **kwargs,
 ):
     r"""
@@ -1262,11 +1278,25 @@ def fit_powerlaw(
     :param exponent: Exponent :math:`b` (fitted if not specified).
     :param axis: Axis to plot along (not plotted if not specified).
     :param fmt: Format for the label (if plotting). E.g. ``r"${0:.3f} x^{{{1:.2f}}}$"``.
-    :param kwargs: Other plot options.
+    :param auto_fmt:
+        Format label (if plotting) as ``r"${0:.3f} x^{{{1:.2f}}}$"``,
+        with ``x`` replaced with the specified string.
+
+    :param extrapolate:
+        Plot the powerlaw on the full range of ``axis.get_xlim()``.
+        Instead of ``True'', one can specify plot options for the extrapolated line, e.g.
+        ``..., extrapolate=dict(ls="--", c="r"), ...``.
+
+    :param kwargs:
+        Other plot options.
 
     :return:
-        ``prefactor, exponent[, h]``
-        The (fitted) prefector and exponent, and optionally the handle (if plotting)
+        ``prefactor, exponent[, plot_details]``
+        The (fitted) prefector and exponent.
+        If plotting, the following details are return as dictionary::
+
+            handle: Handle of the plot.
+            label: Label (if ``fmt`` was specified).
     """
 
     xdata = np.array(xdata)
@@ -1283,7 +1313,7 @@ def fit_powerlaw(
     fit_opts = {}
 
     if yerr is not None:
-        logyerr = np.log(yerr[i])
+        logyerr = np.log(np.array(yerr)[i])
         logyerr = logyerr[~j]
         fit_opts["sigma"] = logyerr
         fit_opts["absolute_sigma"] = True
@@ -1294,19 +1324,39 @@ def fit_powerlaw(
         return (prefactor, exponent)
 
     xp = np.array([np.min(np.exp(logx)), np.max(np.exp(logx))])
+    xl = np.array([axis.get_xlim()[0], xp[0]])
+    xu = np.array([xp[1], axis.get_xlim()[1]])
+    details = {}
+
+    if isinstance(extrapolate, bool) and extrapolate:
+        xp = np.array(axis.get_xlim())
 
     if axis.get_xscale() != "log" or axis.get_yscale() != "log":
         xp = np.logspace(np.log10(xp[0]), np.log10(xp[-1]), 1000)
+        xl = np.logspace(np.log10(xl[0]), np.log10(xl[-1]), 1000)
+        xu = np.logspace(np.log10(xu[0]), np.log10(xu[-1]), 1000)
 
     yp = prefactor * xp ** exponent
+    yl = prefactor * xl ** exponent
+    yu = prefactor * xu ** exponent
+
+    if auto_fmt:
+        assert fmt is None
+        fmt = r"${0:.3f} " + auto_fmt + r"^{{{1:.2f}}}$"
 
     if fmt:
         assert "label" not in kwargs
-        kwargs["label"] = fmt.format(prefactor, exponent)
+        label = fmt.format(prefactor, exponent)
+        kwargs["label"] = label
+        details["label"] = label
 
-    h = axis.plot(xp, yp, **kwargs)
+    details["handle"] = axis.plot(xp, yp, **kwargs)
 
-    return (prefactor, exponent, h)
+    if isinstance(extrapolate, dict):
+        details["handle_lower"] = axis.plot(xl, yl, **extrapolate)
+        details["handle_upper"] = axis.plot(xu, yu, **extrapolate)
+
+    return (prefactor, exponent, details)
 
 
 def fit_exp(
@@ -1317,6 +1367,8 @@ def fit_exp(
     exponent: float = None,
     axis: plt.Axes = None,
     fmt: str = None,
+    auto_fmt: str = None,
+    extrapolate: bool | dict = False,
     **kwargs,
 ):
     r"""
@@ -1336,11 +1388,25 @@ def fit_exp(
     :param exponent: Exponent :math:`b` (fitted if not specified).
     :param axis: Axis to plot along (not plotted if not specified).
     :param fmt: Format for the label (if plotting). E.g. ``r"${0:.3f} \exp ({1:.2f} x)$"``.
-    :param kwargs: Other plot options.
+    :param auto_fmt:
+        Format label (if plotting) as ``r"${0:.3f} \exp ({1:.2f} x)$"``,
+        with ``x`` replaced with the specified string.
+
+    :param extrapolate:
+        Plot the powerlaw on the full range of ``axis.get_xlim()``.
+        Instead of ``True'', one can specify plot options for the extrapolated line, e.g.
+        ``..., extrapolate=dict(ls="--", c="r"), ...``.
+
+    :param kwargs:
+        Other plot options.
 
     :return:
-        ``prefactor, exponent[, h]``
-        The (fitted) prefector and exponent, and optionally the handle (if plotting)
+        ``prefactor, exponent[, plot_details]``
+        The (fitted) prefector and exponent.
+        If plotting, the following details are return as dictionary::
+
+            handle: Handle of the plot.
+            label: Label (if ``fmt`` was specified).
     """
 
     xdata = np.array(xdata)
@@ -1357,7 +1423,7 @@ def fit_exp(
     fit_opts = {}
 
     if yerr is not None:
-        logyerr = np.log(yerr[i])
+        logyerr = np.log(np.array(yerr)[i])
         logyerr = logyerr[~j]
         fit_opts["sigma"] = logyerr
         fit_opts["absolute_sigma"] = True
@@ -1368,19 +1434,39 @@ def fit_exp(
         return (prefactor, exponent)
 
     xp = np.array([np.min(x), np.max(x)])
+    xl = np.array([axis.get_xlim()[0], xp[0]])
+    xu = np.array([xp[1], axis.get_xlim()[1]])
+    details = {}
+
+    if isinstance(extrapolate, bool) and extrapolate:
+        xp = np.array(axis.get_xlim())
 
     if axis.get_yscale() != "log":
         xp = np.linspace(xp[0], xp[-1], 1000)
+        xl = np.linspace(xl[0], xl[-1], 1000)
+        xu = np.linspace(xu[0], xu[-1], 1000)
 
     yp = prefactor * np.exp(exponent * xp)
+    yl = prefactor * np.exp(exponent * xl)
+    yu = prefactor * np.exp(exponent * xu)
+
+    if auto_fmt:
+        assert fmt is None
+        fmt = r"${0:.3f} \exp ({1:.2f} " + auto_fmt + r")$"
 
     if fmt:
         assert "label" not in kwargs
-        kwargs["label"] = fmt.format(prefactor, exponent)
+        label = fmt.format(prefactor, exponent)
+        kwargs["label"] = label
+        details["label"] = label
 
-    h = axis.plot(xp, yp, **kwargs)
+    details["handle"] = axis.plot(xp, yp, **kwargs)
 
-    return (prefactor, exponent, h)
+    if isinstance(extrapolate, dict):
+        details["handle_lower"] = axis.plot(xl, yl, **extrapolate)
+        details["handle_upper"] = axis.plot(xu, yu, **extrapolate)
+
+    return (prefactor, exponent, details)
 
 
 def fit_linear(
@@ -1391,6 +1477,8 @@ def fit_linear(
     slope: float = None,
     axis: plt.Axes = None,
     fmt: str = None,
+    auto_fmt: str = None,
+    extrapolate: bool | dict = False,
     **kwargs,
 ):
     r"""
@@ -1403,11 +1491,25 @@ def fit_linear(
     :param slope: Slope :math:`b` (fitted if not specified).
     :param axis: Axis to plot along (not plotted if not specified).
     :param fmt: Format for the label (if plotting). E.g. ``r"${0:.3f} + {1:.2f} x$"``.
-    :param kwargs: Other plot options.
+    :param auto_fmt:
+        Format label (if plotting) as ``r"${0:.3f} + {1:.2f} x$"``,
+        with ``x`` replaced with the specified string.
+
+    :param extrapolate:
+        Plot the powerlaw on the full range of ``axis.get_xlim()``.
+        Instead of ``True'', one can specify plot options for the extrapolated line, e.g.
+        ``..., extrapolate=dict(ls="--", c="r"), ...``.
+
+    :param kwargs:
+        Other plot options.
 
     :return:
-        ``offset, slope[, h]``
-        The (fitted) offset and slope, and optionally the handle (if plotting)
+        ``offset, slope[, plot_details]``
+        The (fitted) offset and slope.
+        If plotting, the following details are return as dictionary::
+
+            handle: Handle of the plot.
+            label: Label (if ``fmt`` was specified).
     """
 
     xdata = np.array(xdata)
@@ -1448,15 +1550,34 @@ def fit_linear(
         return (offset, slope)
 
     xp = np.array([np.min(xdata), np.max(xdata)])
+    xl = np.array([axis.get_xlim()[0], xp[0]])
+    xu = np.array([xp[1], axis.get_xlim()[1]])
+    details = {}
+
+    if isinstance(extrapolate, bool) and extrapolate:
+        xp = np.array(axis.get_xlim())
+
     yp = offset + slope * xp
+    yl = offset + slope * xl
+    yu = offset + slope * xu
+
+    if auto_fmt:
+        assert fmt is None
+        fmt = r"${0:.3f} + {1:.2f} " + auto_fmt + r"$"
 
     if fmt:
         assert "label" not in kwargs
-        kwargs["label"] = fmt.format(offset, slope)
+        label = fmt.format(offset, slope)
+        kwargs["label"] = label
+        details["label"] = label
 
-    h = axis.plot(xp, yp, **kwargs)
+    details["handle"] = axis.plot(xp, yp, **kwargs)
 
-    return (offset, slope, h)
+    if isinstance(extrapolate, dict):
+        details["handle_lower"] = axis.plot(xl, yl, **extrapolate)
+        details["handle_upper"] = axis.plot(xu, yu, **extrapolate)
+
+    return (offset, slope, details)
 
 
 def random_from_cdf(shape, P, x, linspace=False, shuffle=True):
